@@ -1,7 +1,6 @@
 #!/usr/bin/env python2.7
 'All post-related functions and objects'
 
-from flask import render_template
 from markdown import markdownFromFile
 from glob import glob
 
@@ -26,7 +25,7 @@ class Post(object):
 		'''Renders post template with content inserted'''
 		template = self.env.get_template('post.html')
 		return template.render(
-				c=self.c,
+				site=self.c,
 				post_content=''.join(self.html_content),
 				style=self.style,
 				title=self.page_title,
